#include "Colour.h"

/*
 * Comment out the three lines below if working on non-windows environment
 * Below lines are useful for spotting out memory leaks with exact line numbers in the code
 */
#ifdef _DEBUG
#define new DEBUG_NEW
#endif

/*
 * initializing static instance to NULL value, globally
 */
Colour* Colour::_instance=0;

Colour* Colour::Initialize(void)
{
	/*
	 * create a single one and only one instance
	 */
	if(_instance)	//! If an instance is already created just return it
		return _instance;
	
	return _instance=new Colour();	//! create an instance
}

Colour* Colour::Instance(void)
{
	/*
	 * access the single-ton instance
	 */
	return _instance;
}

void Colour::Destroy(void)
{
	delete _instance;
}

Colour::Colour(void)
{
	/*
	 * Initial colour set to white and with no transperancy
	 */
	_colours[0]=1.0;
	_colours[1]=1.0;
	_colours[2]=1.0;
	_colours[3]=1.0;
	_RGBAColours[0]=255;
	_RGBAColours[1]=255;
	_RGBAColours[2]=255;
	_RGBAColours[3]=255;
}

Colour::Colour(GLubyte R, GLubyte G, GLubyte B)
{
	/*
	 * initial alpha value set to one as it has been never become necessary
	 */
	_colours[3]=1.0;
	_RGBAColours[0]=R;
	_RGBAColours[1]=G;
	_RGBAColours[2]=B;
	_RGBAColours[3]=255;
	RGBToOpenGLColours();
}

Colour::Colour(double *colours)
{
	_colours[0]=colours[0];
	_colours[1]=colours[1];
	_colours[2]=colours[2];
	_colours[3]=colours[3];
}

Colour::~Colour(void)
{
}

double* Colour::CurrColour(void)
{
	return _colours;
}

void Colour::Alpha(float A)
{
	_colours[3]=A;
}

/*
 * The function RGBToOpenGLColours interpolates the RGB values between 0 and 1 for the purpose of OpenGL usage,
 * The formula used here is ( 1 - ( ( 255 - x ) / 255 ) ), where x is an R, G or B colour in the range 0 < x <= 255.
 */
double* Colour::RGBToOpenGLColours()
{
	_colours[0]=1.0-((255.0-_RGBAColours[0])/255.0);
	_colours[1]=1.0-((255.0-_RGBAColours[1])/255.0);
	_colours[2]=1.0-((255.0-_RGBAColours[2])/255.0);
	_colours[3]=1.0-((255.0-_RGBAColours[3])/255.0);
	return _colours;
}

double* Colour::RGBToOpenGLColoursUS()
{
	_colours[0]=1.0-((65535.0-_ushortRGBAColours[0])/65535.0);
	_colours[1]=1.0-((65535.0-_ushortRGBAColours[1])/65535.0);
	_colours[2]=1.0-((65535.0-_ushortRGBAColours[2])/65535.0);
	_colours[3]=1.0-((65535.0-_ushortRGBAColours[3])/65535.0);
	return _colours;
}

const Colour& Colour::operator =(const Colour &tempColour)
{
	_colours[0]=tempColour._colours[0];
	_colours[1]=tempColour._colours[1];
	_colours[2]=tempColour._colours[2];
	_colours[3]=tempColour._colours[3];
	return *this;
}

const Colour& Colour::operator =(const double *colourVals)
{
	_colours[0]=colourVals[0];
	_colours[1]=colourVals[1];
	_colours[2]=colourVals[2];
	_colours[3]=colourVals[3];
	return *this;
}

//double* Colour::GetColour(unsigned short R, unsigned short G, unsigned short B, unsigned short A)
//{
//	_ushortRGBAColours[0]=R;
//    _ushortRGBAColours[1]=G;
//	_ushortRGBAColours[2]=B;
//	_ushortRGBAColours[3]=A;
//	return RGBToOpenGLColoursUS();
//}

double* Colour::White(void)
{
	_colours[0]=1.0;
	_colours[1]=1.0;
	_colours[2]=1.0;
	return _colours;
}

double* Colour::Black(void)
{
	_colours[0]=0.0;
	_colours[1]=0.0;
	_colours[2]=0.0;
	return _colours;
}

double* Colour::Red(void)
{
	_colours[0]=1.0;
	_colours[1]=0.0;
	_colours[2]=0.0;
	return _colours;
}

double* Colour::Green(void)
{
	_colours[0]=0.0;
	_colours[1]=1.0;
	_colours[2]=0.0;
	return _colours;
}

double* Colour::Blue(void)
{
	_colours[0]=0.0;
	_colours[1]=0.0;
	_colours[2]=1.0;
	return _colours;
}

double* Colour::Yellow(void)
{
	_colours[0]=1.0;
	_colours[1]=1.0;
	_colours[2]=0.0;
	return _colours;
}

double* Colour::Cyan(void)
{
	_colours[0]=0.0;
	_colours[1]=1.0;
	_colours[2]=1.0;
	return _colours;
}

double* Colour::Magenta(void)
{
	_colours[0]=1.0;
	_colours[1]=0.0;
	_colours[2]=1.0;
	return _colours;
}

/*
RGB values obtained from http://www.help4web.net/webmaster/Color/RGB-Values.html and http://www.oreilly.com/catalog/wdnut/excerpt/color_names.html O'Reilly & Associates, Inc.
accessed 8 june 04 and 30 june 04 , respectively.
*/

/*
funtion names named after colours represented by RGB values.
return value - An array of OpenGL colours equivalent to RGBA
*/
double* Colour::Violet(void)
{
	/*
	RGB values for dark violet has been used. Pure violet colour has RGB=238, 130, 238, which is nearly equal to orchid colour
	*/
	_RGBAColours[0]=148;
	_RGBAColours[1]=0;
	_RGBAColours[2]=211;
	return RGBToOpenGLColours();
}

double* Colour::Indigo(void)
{
	_RGBAColours[0]=75;
	_RGBAColours[1]=0;
	_RGBAColours[2]=130;
	return RGBToOpenGLColours();
}

double* Colour::Orange(void)
{
	_RGBAColours[0]=255;
	_RGBAColours[1]=165;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::Gray(void)
{
	_RGBAColours[0]=190;
    	_RGBAColours[1]=190;
	_RGBAColours[2]=190;
	return RGBToOpenGLColours();
}

double* Colour::Brown(void)
{
	_RGBAColours[0]=165;
    	_RGBAColours[1]=42;
	_RGBAColours[2]=42;
	return RGBToOpenGLColours();
}

double* Colour::Gold(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=215;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::Snow(void)
{
	_RGBAColours[0]=255;
	_RGBAColours[1]=250;
	_RGBAColours[2]=250;
	return RGBToOpenGLColours();
}

double* Colour::Ghostwhite(void)
{
	_RGBAColours[0]=248;
	_RGBAColours[1]=248;
	_RGBAColours[2]=255;
	return RGBToOpenGLColours();
}

double* Colour::WhiteSmoke(void) 
{
	_RGBAColours[0]=245;
	_RGBAColours[1]=245;
	_RGBAColours[2]=245;
	return RGBToOpenGLColours();
}

double* Colour::Gainsboro(void)
{
	_RGBAColours[0]=220;
	_RGBAColours[1]=220;
	_RGBAColours[2]=220;
	return RGBToOpenGLColours();
}

double* Colour::FloralWhite(void)
{
	_RGBAColours[0]=255;
	_RGBAColours[1]=250;
	_RGBAColours[2]=240;
	return RGBToOpenGLColours();
}

double* Colour::OldLace(void)
{
	_RGBAColours[0]=253;
	_RGBAColours[1]=245;
	_RGBAColours[2]=230;
	return RGBToOpenGLColours();
}

double* Colour::Linen(void) 
{
	_RGBAColours[0]=250;
	_RGBAColours[1]=240;
	_RGBAColours[2]=230;
	return RGBToOpenGLColours();
}

double* Colour::AntiqueWhite(void)
{
	_RGBAColours[0]=250;
	_RGBAColours[1]=235;
	_RGBAColours[2]=215;
	return RGBToOpenGLColours();
}

double* Colour::PapayaWhip(void) 
{
	_RGBAColours[0]=255;
	_RGBAColours[1]=239;
	_RGBAColours[2]=213;
	return RGBToOpenGLColours();
}

double* Colour::BlanchedAlmond(void)
{
	_RGBAColours[0]=255;
	_RGBAColours[1]=235;
	_RGBAColours[2]=205;
	return RGBToOpenGLColours();
}

double* Colour::Bisque(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=228;
	_RGBAColours[2]=196;
	return RGBToOpenGLColours();
}

double* Colour::PeachPuff(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=218;
	_RGBAColours[2]=185;
	return RGBToOpenGLColours();
}

double* Colour::NavajoWhite(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=222;
	_RGBAColours[2]=173;
	return RGBToOpenGLColours();
}

double* Colour::Moccasin(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=228;
	_RGBAColours[2]=181;
	return RGBToOpenGLColours();
}

double* Colour::CornSilk(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=248;
	_RGBAColours[2]=220;
	return RGBToOpenGLColours();
}

double* Colour::Ivory(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=240;
	return RGBToOpenGLColours();
}

double* Colour::LemonChiffon(void)  
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=250;
	_RGBAColours[2]=205;
	return RGBToOpenGLColours();
}

double* Colour::SeaShell(void)  
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=245;
	_RGBAColours[2]=238;
	return RGBToOpenGLColours();
}

double* Colour::HoneyDew(void)
{
	_RGBAColours[0]=240;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=240;
	return RGBToOpenGLColours();
}

double* Colour::MintCream(void) 
{
	_RGBAColours[0]=245;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=250;
	return RGBToOpenGLColours();
}

double* Colour::Azure(void) 
{
	_RGBAColours[0]=240;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=255;
	return RGBToOpenGLColours();
}

double* Colour::AliceBlue(void)  
{
	_RGBAColours[0]=240;
    	_RGBAColours[1]=248;
	_RGBAColours[2]=255;
	return RGBToOpenGLColours();
}

double* Colour::Lavender(void)  
{
	_RGBAColours[0]=230;
    	_RGBAColours[1]=230;
	_RGBAColours[2]=250;
	return RGBToOpenGLColours();
}

double* Colour::LavenderBlush(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=240;
	_RGBAColours[2]=245;
	return RGBToOpenGLColours();
}

double* Colour::MistyRose(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=228;
	_RGBAColours[2]=225;
	return RGBToOpenGLColours();
}

double* Colour::DarkSlateGray(void) 
{
	_RGBAColours[0]=47;
    	_RGBAColours[1]=79;
	_RGBAColours[2]=79;
	return RGBToOpenGLColours();
}

double* Colour::DimGray(void)  
{
	_RGBAColours[0]=105;
    	_RGBAColours[1]=105;
	_RGBAColours[2]=105;
	return RGBToOpenGLColours();
}

double* Colour::SlateGray(void)  
{
	_RGBAColours[0]=112;
    	_RGBAColours[1]=128;
	_RGBAColours[2]=144;
	return RGBToOpenGLColours();
}

double* Colour::LightSlateGray(void) 
{
	_RGBAColours[0]=119;
    	_RGBAColours[1]=136;
	_RGBAColours[2]=153;
	return RGBToOpenGLColours();
}

double* Colour::LightGrey(void)  
{
	_RGBAColours[0]=211;
    	_RGBAColours[1]=211;
	_RGBAColours[2]=211;
	return RGBToOpenGLColours();
}

double* Colour::MidnightBlue(void)  
{
	_RGBAColours[0]=25;
    	_RGBAColours[1]=25;
	_RGBAColours[2]=112;
	return RGBToOpenGLColours();
}

double* Colour::NavyBlue(void) 
{
	_RGBAColours[0]=0;
    	_RGBAColours[1]=0;
	_RGBAColours[2]=128;
	return RGBToOpenGLColours();
}

double* Colour::CornFlowerBlue(void)
{
	_RGBAColours[0]=100;
    	_RGBAColours[1]=149;
	_RGBAColours[2]=237;
	return RGBToOpenGLColours();
}

double* Colour::DarkSlateBlue(void)  
{
	_RGBAColours[0]=72;
    	_RGBAColours[1]=61;
	_RGBAColours[2]=139;
	return RGBToOpenGLColours();
}

double* Colour::SlateBlue(void)
{
	_RGBAColours[0]=106;
    	_RGBAColours[1]=90;
	_RGBAColours[2]=205;
	return RGBToOpenGLColours();
}

double* Colour::MediumSlateBlue(void) 
{
	_RGBAColours[0]=123;
    	_RGBAColours[1]=104;
	_RGBAColours[2]=238;
	return RGBToOpenGLColours();
}

double* Colour::RoyalBlue(void)  
{
	_RGBAColours[0]=65;
    	_RGBAColours[1]=105;
	_RGBAColours[2]=225;
	return RGBToOpenGLColours();
}

double* Colour::DodgerBlue(void) 
{
	_RGBAColours[0]=30;
    	_RGBAColours[1]=144;
	_RGBAColours[2]=255;
	return RGBToOpenGLColours();
}

double* Colour::DeepSkyBlue(void)  
{
	_RGBAColours[0]=0;
    	_RGBAColours[1]=191;
	_RGBAColours[2]=255;
	return RGBToOpenGLColours();
}

double* Colour::SkyBlue(void)
{
	_RGBAColours[0]=135;
    	_RGBAColours[1]=206;
	_RGBAColours[2]=235;
	return RGBToOpenGLColours();
}

double* Colour::LightSkyBlue(void) 
{
	_RGBAColours[0]=135;
    	_RGBAColours[1]=205;
	_RGBAColours[2]=250;
	return RGBToOpenGLColours();
}

double* Colour::SteelBlue(void)  
{
	_RGBAColours[0]=70;
    	_RGBAColours[1]=130;
	_RGBAColours[2]=180;
	return RGBToOpenGLColours();
}

double* Colour::LightBlue(void)  
{
	_RGBAColours[0]=173;
    	_RGBAColours[1]=216;
	_RGBAColours[2]=230;
	return RGBToOpenGLColours();
}

double* Colour::PowderBlue(void) 
{
	_RGBAColours[0]=176;
    	_RGBAColours[1]=224;
	_RGBAColours[2]=230;
	return RGBToOpenGLColours();
}

double* Colour::PaleTurquoise(void) 
{
	_RGBAColours[0]=175;
    	_RGBAColours[1]=238;
	_RGBAColours[2]=238;
	return RGBToOpenGLColours();
}

double* Colour::DarkTurquoise(void)
{
	_RGBAColours[0]=0;
    	_RGBAColours[1]=206;
	_RGBAColours[2]=209;
	return RGBToOpenGLColours();
}

double* Colour::Turquoise(void)
{
	_RGBAColours[0]=64;
    	_RGBAColours[1]=224;
	_RGBAColours[2]=208;
	return RGBToOpenGLColours();
}

double* Colour::CadetBlue(void) 
{
	_RGBAColours[0]=95;
    	_RGBAColours[1]=158;
	_RGBAColours[2]=160;
	return RGBToOpenGLColours();
}

double* Colour::MediumAquamarine(void)
{
	_RGBAColours[0]=102;
    	_RGBAColours[1]=205;
	_RGBAColours[2]=170;
	return RGBToOpenGLColours();
}

double* Colour::DarkOliveGreen(void)  
{
	_RGBAColours[0]=85;
    	_RGBAColours[1]=105;
	_RGBAColours[2]=47;
	return RGBToOpenGLColours();
}

double* Colour::DarkSeaGreen(void)
{
	_RGBAColours[0]=143;
    	_RGBAColours[1]=188;
	_RGBAColours[2]=143;
	return RGBToOpenGLColours();
}

double* Colour::SeaGreen(void)
{
	_RGBAColours[0]=46;
    	_RGBAColours[1]=139;
	_RGBAColours[2]=87;
	return RGBToOpenGLColours();
}

double* Colour::PaleGreen(void)
{
	_RGBAColours[0]=152;
    	_RGBAColours[1]=251;
	_RGBAColours[2]=152;
	return RGBToOpenGLColours();
}

double* Colour::SpringGreen(void)
{
	_RGBAColours[0]=0;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=127;
	return RGBToOpenGLColours();
}

double* Colour::LawnGreen(void)
{
	_RGBAColours[0]=124;
    	_RGBAColours[1]=252;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::ChartReUse(void)
{
	_RGBAColours[0]=127;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::GreenYellow(void) 
{
	_RGBAColours[0]=173;
    	_RGBAColours[1]=255;
	_RGBAColours[2]=47;
	return RGBToOpenGLColours();
}

double* Colour::ForestGreen(void)
{
	_RGBAColours[0]=34;
    	_RGBAColours[1]=139;
	_RGBAColours[2]=34;
	return RGBToOpenGLColours();
}

double* Colour::DarkKhaki(void)
{
	_RGBAColours[0]=189;
    	_RGBAColours[1]=183;
	_RGBAColours[2]=107;
	return RGBToOpenGLColours();
}

double* Colour::Khaki(void) 
{
	_RGBAColours[0]=240;
    	_RGBAColours[1]=230;
	_RGBAColours[2]=140;
	return RGBToOpenGLColours();
}

double* Colour::RosyBrown(void) 
{
	_RGBAColours[0]=188;
    	_RGBAColours[1]=143;
	_RGBAColours[2]=143;
	return RGBToOpenGLColours();
}

double* Colour::IndianRed(void) 
{
	_RGBAColours[0]=205;
    	_RGBAColours[1]=92;
	_RGBAColours[2]=92;
	return RGBToOpenGLColours();
}

double* Colour::SaddleBrown(void)
{
	_RGBAColours[0]=139;
    	_RGBAColours[1]=69;
	_RGBAColours[2]=69;
	return RGBToOpenGLColours();
}

double* Colour::Sienna(void)  
{
	_RGBAColours[0]=160;
    	_RGBAColours[1]=82;
	_RGBAColours[2]=45;
	return RGBToOpenGLColours();
}

double* Colour::Peru(void)
{
	_RGBAColours[0]=205;
    	_RGBAColours[1]=133;
	_RGBAColours[2]=63;
	return RGBToOpenGLColours();
}

double* Colour::BurlyWood(void) 
{
	_RGBAColours[0]=222;
    	_RGBAColours[1]=184;
	_RGBAColours[2]=135;
	return RGBToOpenGLColours();
}

double* Colour::Beige(void)
{
	_RGBAColours[0]=245;
    	_RGBAColours[1]=245;
	_RGBAColours[2]=220;
	return RGBToOpenGLColours();
}

double* Colour::Wheat(void)  
{
	_RGBAColours[0]=245;
    	_RGBAColours[1]=222;
	_RGBAColours[2]=179;
	return RGBToOpenGLColours();
}

double* Colour::SandyBrown(void) 
{
	_RGBAColours[0]=244;
    	_RGBAColours[1]=164;
	_RGBAColours[2]=96;
	return RGBToOpenGLColours();
}

double* Colour::Tan(void) 
{
	_RGBAColours[0]=210;
    	_RGBAColours[1]=180;
	_RGBAColours[2]=140;
	return RGBToOpenGLColours();
}

double* Colour::Chocolate(void)
{
	_RGBAColours[0]=210;
    	_RGBAColours[1]=105;
	_RGBAColours[2]=30;
	return RGBToOpenGLColours();
}

double* Colour::FireBrick(void)
{
	_RGBAColours[0]=178;
    	_RGBAColours[1]=34;
	_RGBAColours[2]=34;
	return RGBToOpenGLColours();
}

double* Colour::DarkSalmon(void)
{
	_RGBAColours[0]=233;
    	_RGBAColours[1]=150;
	_RGBAColours[2]=122;
	return RGBToOpenGLColours();
}

double* Colour::Salmon(void) 
{
	_RGBAColours[0]=250;
    	_RGBAColours[1]=128;
	_RGBAColours[2]=114;
	return RGBToOpenGLColours();
}

double* Colour::DarkOrange(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=140;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::Coral(void)  
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=127;
	_RGBAColours[2]=80;
	return RGBToOpenGLColours();
}

double* Colour::LightCoral(void)  
{
	_RGBAColours[0]=240;
    	_RGBAColours[1]=128;
	_RGBAColours[2]=128;
	return RGBToOpenGLColours();
}

double* Colour::Tomato(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=99;
	_RGBAColours[2]=71;
	return RGBToOpenGLColours();
}

double* Colour::OrangeRed(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=69;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::HotPink(void)  
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=105;
	_RGBAColours[2]=180;
	return RGBToOpenGLColours();
}

double* Colour::DeepPink(void)
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=20;
	_RGBAColours[2]=147;
	return RGBToOpenGLColours();
}

double* Colour::Pink(void) 
{
	_RGBAColours[0]=255;
    	_RGBAColours[1]=192;
	_RGBAColours[2]=203;
	return RGBToOpenGLColours();
}

double* Colour::PaleVioletRed(void) 
{
	_RGBAColours[0]=219;
    	_RGBAColours[1]=112;
	_RGBAColours[2]=147;
	return RGBToOpenGLColours();
}

double* Colour::Maroon(void)
{
	_RGBAColours[0]=176;
    	_RGBAColours[1]=48;
	_RGBAColours[2]=96;
	return RGBToOpenGLColours();
}

double* Colour::MediumVioletRed(void)
{
	_RGBAColours[0]=199;
    	_RGBAColours[1]=21;
	_RGBAColours[2]=133;
	return RGBToOpenGLColours();
}

double* Colour::Plum(void) 
{
	_RGBAColours[0]=221;
    	_RGBAColours[1]=160;
	_RGBAColours[2]=221;
	return RGBToOpenGLColours();
}

double* Colour::Orchid(void)  
{
	_RGBAColours[0]=218;
    	_RGBAColours[1]=112;
	_RGBAColours[2]=214;
	return RGBToOpenGLColours();
}

double* Colour::BlueViolet(void) 
{
	_RGBAColours[0]=138;
    	_RGBAColours[1]=43;
	_RGBAColours[2]=226;
	return RGBToOpenGLColours();
}

double* Colour::Purple(void)  
{
	_RGBAColours[0]=160;
    	_RGBAColours[1]=32;
	_RGBAColours[2]=240;
	return RGBToOpenGLColours();
}

double* Colour::DarkGray(void)
{
	_RGBAColours[0]=169;
    	_RGBAColours[1]=169;
	_RGBAColours[2]=169;
	return RGBToOpenGLColours();
}

double* Colour::DarkCyan(void) 
{
	_RGBAColours[0]=0;
    	_RGBAColours[1]=139;
	_RGBAColours[2]=139;
	return RGBToOpenGLColours();
}

double* Colour::DarkMagenta(void)  
{
	_RGBAColours[0]=139;
    	_RGBAColours[1]=0;
	_RGBAColours[2]=139;
	return RGBToOpenGLColours();
}

double* Colour::DarkRed(void) 
{
	_RGBAColours[0]=139;
    	_RGBAColours[1]=0;
	_RGBAColours[2]=0;
	return RGBToOpenGLColours();
}

double* Colour::LightGreen(void)
{
	_RGBAColours[0]=144;
    	_RGBAColours[1]=238;
	_RGBAColours[2]=144;
	return RGBToOpenGLColours();
}
